## INSTRUCTIONS:
## Place a webp thumbnail in add_new/thumbnails.
## and Place a webm or webp content in add_new/content.
## Then run this script.
## Thumbnails and content must match or this program will crash.
##
## Content warnings can be added as arguments separated by a space.

## Currently accepted content warnings: 
## alexandra, celeste, knife, smoking


## This script requires pillow: pip install pillow
from PIL import Image
from datetime import datetime
import json
import shutil
import os
import sys

def write_json(new_data, filename='gallery/masterlist.json'):
	with open(filename, 'r+') as file:
		file_data = json.load(file) # Load existing data into dict.
		file_data["data"].append(new_data) # Join new data with existing data.
		file.seek(0) # Sets file's current position at offset.
		json.dump(file_data, file, indent=4)

def find_content(filename, content_list):
    i = 0
    for content in content_list:
        content_filename = content.split('.')[0]

        if filename == content_filename:
            return i

        i+=1

add_new_content = "gallery/add_new/content/"
add_new_thumbnails = "gallery/add_new/thumbnails/"

gallery_content = "gallery/content/"
gallery_thumbnails = "gallery/thumbnails/"

##---------

content_list = os.listdir(add_new_content)
thumbnails_list = os.listdir(add_new_thumbnails)

for thumbnail in thumbnails_list:
    # Check if the image is a webp
    if thumbnail.split('.')[-1] != "webp":
        print("Error: " + thumbnail + " Is not a webp image.")
        continue

    filename = thumbnail.split('.')[0]
    content_index = find_content(filename, content_list)

    if content_list[content_index].split('.')[-1] != "webp" and content_list[content_index].split('.')[-1] != "webm":
        print("Error: " + content_list[content_index] + " Is not a webp or webm file.")
        continue
    
    thumbnail_img = Image.open(thumbnail)
    thumbnail_img.show()

    print("\nPlease insert any content warnings as a comma (,) separated list:")
    content_warnings = input()

    print("\nPlease insert any comments you want to add to the video:")
    comments = input()

    data = {
        'thumbnail_path' : gallery_thumbnails + thumbnail,
        'content_path' : gallery_content + content_list[content_index],
        'video' : False,
        'content_warnings' : content_warnings,
        'comments': comments,
        'date_added' : datetime.now().strftime('%Y-%m-%d %H:%M:%S')
    }

    if content_list[content_index].split('.')[-1] == "webm":
        data["video"] = True

    write_json(data)

    # Move the files from the add_new folder to gallery
    shutil.move(add_new_content + content_list[content_index], gallery_content + content_list[content_index])
    shutil.move(add_new_thumbnails + thumbnail, gallery_thumbnails + thumbnail)