let content_warnings = {
    "alexandra": "show",
    "celeste":   "show",
    "knife":     "blur",
    "smoking":   "show",
};

let LOCAL_STORAGE_CONTENT_WARNING_PREFIX = "gallery_content_warning";

async function get_masterlist() {
    let response = await fetch('/gallery/masterlist.json');
    let masterlist = await response.text();

    masterlist = JSON.parse(masterlist);

    return masterlist
}

function setup_close_overlay() {
    let gallery_overlay = document.getElementById("gallery_overlay");
    
    gallery_overlay.onclick = function(event){
        if (event.target.nodeName != "IMG" && event.target.nodeName != "VIDEO") { // Make sure the person isn't trying to click on the image.

            document.getElementsByTagName("body")[0].style.overflow = "auto";
            document.getElementById("gallery_overlay").style.display = "none";
        
            let all_elements = document.getElementsByTagName("*");
            for (var i = all_elements.length; i--;) { // Apparently iterating in reverse is slightly faster.
                if (all_elements[i].id != "close_overlay") {
                    all_elements[i].removeAttribute("tabindex")
                }
            }

            document.getElementById("temp").remove(); // Delete the element when done with it.
        }
    }
}

function update_content_warnings(event) {
    let content_warning = event.target.id;

    local_storage_key = LOCAL_STORAGE_CONTENT_WARNING_PREFIX + '.' + content_warning.split('.')[0];
    localStorage.setItem(local_storage_key, content_warning.split('.')[1]);
}

function refresh_page(){
    window.location.reload();
}

function display_content_selector(event) {
    event.target.parentNode.style.display = "none";
    this.document.getElementById("gallery_content_selector_blur").style.display = "block";

    let height = (document.getElementsByClassName("container")[0].getBoundingClientRect().height - 10 ) +"px";
        let width = document.getElementsByClassName("container")[0].getBoundingClientRect().width +"px";

        let gallery_content_selector_blur = this.document.getElementById("gallery_content_selector_blur")
        gallery_content_selector_blur.style.height = height;
        gallery_content_selector_blur.style.width = width;

        window.addEventListener('resize', function () {
            let height = (document.getElementsByClassName("container")[0].getBoundingClientRect().height - 10 ) +"px";
            let width = document.getElementsByClassName("container")[0].getBoundingClientRect().width +"px";
    
            let gallery_content_selector_blur = this.document.getElementById("gallery_content_selector_blur")
            gallery_content_selector_blur.style.height = height;
            gallery_content_selector_blur.style.width = width;
        });
}

async function generate_gallery() {
    let masterlist = await get_masterlist();
    masterlist = masterlist.data.reverse(); // Reverse the json data since most recent content is appended.

    // Content warning stuff.
    let gallery_content_selectors_div = document.getElementById("gallery_content_selector");
    let gallery_content_selectors_template_form = document.getElementById("template.selector");

    for (let key in content_warnings) {
        let local_storage_key = LOCAL_STORAGE_CONTENT_WARNING_PREFIX + '.' + key;
        
        if (localStorage.getItem(local_storage_key) == null) {
            localStorage.setItem(local_storage_key, content_warnings[key]);
        }
        else {
            content_warnings[key] = localStorage.getItem(local_storage_key);
        }

        let gallery_content_selector_form = gallery_content_selectors_template_form.cloneNode(deep = true);
        gallery_content_selector_form.style.display = "block";
        gallery_content_selector_form.id = key + ".selector"
        gallery_content_selector_form.innerHTML = gallery_content_selector_form.innerHTML.replaceAll("template", key);

        gallery_content_selectors_div.appendChild(gallery_content_selector_form);

        if      (content_warnings[key] == "show") { document.getElementById(key + ".show").checked = true; }
        else if (content_warnings[key] == "blur") { document.getElementById(key + ".blur").checked = true; }
        else if (content_warnings[key] == "hide") { document.getElementById(key + ".hide").checked = true; }
    }

    let reload_button = document.createElement("button");
    reload_button.innerText = "Apply changes:";
    reload_button.onclick = refresh_page;
    gallery_content_selectors_div.appendChild(reload_button);

    for (let x = 0; x < masterlist.length; x+=1) {
        for (key in content_warnings) {
            if (masterlist[x].content_warnings.includes(key)) {
                if (content_warnings[key] == "blur") {
                    masterlist[x].blur = true;
                }
                else if (content_warnings[key] == "hide") {
                    masterlist[x].hide = true;
                }
            }
        }
        if (masterlist[x].hide == true) {
            masterlist.splice(x, 1);
            x -=1;
        }
    }

    // End of content warning stuff.

    // Populate the gallery with images n crap.
    for (let i in masterlist) {
        let thumbnail = document.createElement('img');
        thumbnail.src=masterlist[i].thumbnail_path;
        thumbnail.loading="lazy";

        let button = document.createElement('button');

        let content_path = masterlist[i].thumbnail_path.replace("/thumbnails/", "/content/");
        if (masterlist[i].video) { // Replace with webp if a video.
            content_path = content_path.replace(".webp", ".webm");
            thumbnail.classList.add("gallery_video");
        }

        if (masterlist[i].blur == true) {
            thumbnail.classList.add("blur");

            let blur_text = document.createElement("p");
            blur_text.innerHTML = "Image contains:<br>" + masterlist[i].content_warnings;
            blur_text.innerHTML = blur_text.innerHTML.replace(',', ", ");

            blur_text.dataset.content_path = content_path;

            button.appendChild(blur_text);
        }

        button.dataset.content_path = content_path;
        thumbnail.dataset.content_path = content_path;

        button.onclick = function(event){
            content_path = event.target.dataset.content_path;

            document.getElementsByTagName("body")[0].style.overflow = "hidden";
            document.getElementById("gallery_overlay").style.display = "block";

            let all_elements = document.getElementsByTagName("*");
            for (var i = all_elements.length; i--;) { // Apparently iterating in reverse is slightly faster.
                if (all_elements[i].id != "close_overlay") {
                    all_elements[i].setAttribute("tabindex", "-1");
                }
            }

            if (content_path.includes(".webm")) {
                let video = document.createElement('video');
                video.muted = true;
                video.src = content_path;
                video.controls = true;
                video.id = "temp";

                document.getElementById("gallery_overlay").appendChild(video);
            } else {
                let image = document.createElement('img');
                image.src = content_path;
                image.id = "temp";

                document.getElementById("gallery_overlay").appendChild(image);
            }
        };

        button.appendChild(thumbnail);
        gallery.appendChild(button);
    }
}

generate_gallery();
setup_close_overlay();