// This is the old code for the gallery that used pages instead of infinite scroll.
// Archived on 2023-12-11, BEFORE we fixed the blurtags.

let content_warnings = {
    "alexandra": "show",
    "celeste":   "show",
    "knife":     "show",
    "smoking":   "show",
};

let LOCAL_STORAGE_CONTENT_WARNING_PREFIX = "gallery_content_warning";

generate_gallery();
setup_close_overlay();

function get_url_param(variable) {
    var query = window.location.search.substring(1);
    var vars = query.split("&");
    for (var i=0;i<vars.length;i++) {
        var pair = vars[i].split("=");
        if (pair[0] == variable) {
            return pair[1];
        }
    }

    insert_url_param("page", 1);
}

function insert_url_param(key, value) { // Shamelessly stolen from: https://stackoverflow.com/a/487049
    key = encodeURIComponent(key);
    value = encodeURIComponent(value);

    // kvp looks like ['key1=value1', 'key2=value2', ...]
    var kvp = document.location.search.substring(1).split('&');
    let i=0;

    for(; i<kvp.length; i++){
        if (kvp[i].startsWith(key + '=')) {
            let pair = kvp[i].split('=');
            pair[1] = value;
            kvp[i] = pair.join('=');
            break;
        }
    }

    if(i >= kvp.length){
        kvp[kvp.length] = [key,value].join('=');
    }

    // can return this or...
    let params = kvp.join('&');

    // reload page with new params
    document.location.search = params;
}


async function get_masterlist() {
    let response = await fetch('/gallery/masterlist.json');
    let masterlist = await response.text();

    masterlist = JSON.parse(masterlist);

    return masterlist
}

function setup_close_overlay() {
    let gallery_overlay = document.getElementById("gallery_overlay");
    
    gallery_overlay.onclick = function(event){
        if (event.target.nodeName != "IMG" && event.target.nodeName != "VIDEO") { // Make sure the person isn't trying to click on the image.

            document.getElementsByTagName("body")[0].style.overflow = "auto";
            document.getElementById("gallery_overlay").style.display = "none";
        
            let all_elements = document.getElementsByTagName("*");
            for (var i = all_elements.length; i--;) { // Apparently iterating in reverse is slightly faster.
                if (all_elements[i].id != "close_overlay") {
                    all_elements[i].removeAttribute("tabindex")
                }
            }

            document.getElementById("temp").remove(); // Delete the element when done with it.
        }
    }
}

function update_content_warnings(event) {
    let content_warning = event.target.id;

    local_storage_key = LOCAL_STORAGE_CONTENT_WARNING_PREFIX + '.' + content_warning.split('.')[0];
    localStorage.setItem(local_storage_key, content_warning.split('.')[1]);
}

function refresh_page(){
    window.location.reload();
}

function display_content_selector(event) {
    event.target.parentNode.style.display = "none";
    this.document.getElementById("gallery_content_selector_blur").style.display = "block";

    let height = (document.getElementsByClassName("container")[0].getBoundingClientRect().height - 10 ) +"px";
        let width = document.getElementsByClassName("container")[0].getBoundingClientRect().width +"px";

        let gallery_content_selector_blur = this.document.getElementById("gallery_content_selector_blur")
        gallery_content_selector_blur.style.height = height;
        gallery_content_selector_blur.style.width = width;

        window.addEventListener('resize', function () {
            let height = (document.getElementsByClassName("container")[0].getBoundingClientRect().height - 10 ) +"px";
            let width = document.getElementsByClassName("container")[0].getBoundingClientRect().width +"px";
    
            let gallery_content_selector_blur = this.document.getElementById("gallery_content_selector_blur")
            gallery_content_selector_blur.style.height = height;
            gallery_content_selector_blur.style.width = width;
        });
}

async function generate_gallery() {
    let masterlist = await get_masterlist();
    masterlist = masterlist.data.reverse(); // Reverse the json data since most recent content is appended.

    // Content warning stuff.
    let gallery_content_selectors_div = document.getElementById("gallery_content_selector");
    let gallery_content_selectors_template_form = document.getElementById("template.selector");

    for (let key in content_warnings) {
        let local_storage_key = LOCAL_STORAGE_CONTENT_WARNING_PREFIX + '.' + key;
        
        if (localStorage.getItem(local_storage_key) == null) {
            localStorage.setItem(local_storage_key, content_warnings[key]);
        }
        else {
            content_warnings[key] = localStorage.getItem(local_storage_key);
        }

        let gallery_content_selector_form = gallery_content_selectors_template_form.cloneNode(deep = true);
        gallery_content_selector_form.style.display = "block";
        gallery_content_selector_form.id = key + ".selector"
        gallery_content_selector_form.innerHTML = gallery_content_selector_form.innerHTML.replaceAll("template", key);

        gallery_content_selectors_div.appendChild(gallery_content_selector_form);

        if      (content_warnings[key] == "show") { document.getElementById(key + ".show").checked = true; }
        else if (content_warnings[key] == "blur") { document.getElementById(key + ".blur").checked = true; }
        else if (content_warnings[key] == "hide") { document.getElementById(key + ".hide").checked = true; }
    }

    let reload_button = document.createElement("button");
    reload_button.innerText = "Apply changes:";
    reload_button.onclick = refresh_page;
    gallery_content_selectors_div.appendChild(reload_button);

    for (let x = 0; x < masterlist.length; x+=1) {
        for (key in content_warnings) {
            if (masterlist[x].content_warnings.includes(key)) {
                if (content_warnings[key] == "blur") {
                    masterlist[x].blur = true;
                }
                else if (content_warnings[key] == "hide") {
                    masterlist[x].hide = true;
                }
            }
        }
        if (masterlist[x].hide == true) {
            masterlist.splice(x, 1);
            x -=1;
        }
    }

    // End of content warning stuff.

    // Use this to avoid infinite reloads
    let is_masterlist_empty = false;
    if (masterlist.length == 0) {
        is_masterlist_empty = true;
    }

    let gallery = document.getElementsByClassName("gallery")[0];

    const SMALL_SCREEN_IMAGE_COUNT = 24;
    const LARGE_SCREEN_IMAGE_COUNT = 50;

    let view_width = window.screen.width;
    
    let count = 0
    if (window.screen.width < 600) {
        count = SMALL_SCREEN_IMAGE_COUNT;
    } else {
        count = LARGE_SCREEN_IMAGE_COUNT;
    }

    let chunked_masterlist = [];
    for (let i = 0; i < masterlist.length; i+= count) {
        chunked_masterlist.push(masterlist.slice(i, i+count));
    }

    let chunk_index = get_url_param("page") -1;
    
    if ((chunk_index < 0 || chunk_index >= chunked_masterlist.length || isNaN(chunk_index)) && is_masterlist_empty == false) { // Avoid people trying to access page -39913 or some dumb shit;
        insert_url_param("page", 1);
    }

    // TODO! Tell people they have hidden all the images cause they are a dingus. (use is_masterlist_empty to check this)

    masterlist = chunked_masterlist[chunk_index];

    // Populate the gallery with images n crap.
    for (let i in masterlist) {
        let thumbnail = document.createElement('img');
        thumbnail.src=masterlist[i].thumbnail_path;
        thumbnail.loading="lazy";

        let button = document.createElement('button');

        let content_path = masterlist[i].thumbnail_path.replace("/thumbnails/", "/content/");
        if (masterlist[i].video) { // Replace with webp if a video.
            content_path = content_path.replace(".webp", ".webm");
            thumbnail.classList.add("gallery_video");
        }

        if (masterlist[i].blur == true) { button.classList.add("blur"); }

        button.dataset.content_path = content_path;
        thumbnail.dataset.content_path = content_path;

        button.onclick = function(event){
            content_path = event.target.dataset.content_path;

            document.getElementsByTagName("body")[0].style.overflow = "hidden";
            document.getElementById("gallery_overlay").style.display = "block";

            let all_elements = document.getElementsByTagName("*");
            for (var i = all_elements.length; i--;) { // Apparently iterating in reverse is slightly faster.
                if (all_elements[i].id != "close_overlay") {
                    all_elements[i].setAttribute("tabindex", "-1");
                }
            }

            if (content_path.includes(".webm")) {
                let video = document.createElement('video');
                video.muted = true;
                video.src = content_path;
                video.controls = true;
                video.id = "temp";

                document.getElementById("gallery_overlay").appendChild(video);
            } else {
                let image = document.createElement('img');
                image.src = content_path;
                image.id = "temp";

                document.getElementById("gallery_overlay").appendChild(image);
            }
        };

        button.appendChild(thumbnail);
        gallery.appendChild(button);
    }

    const NAV_BAR_RANGE = 3;

    let forward = 0;
    let backward = 0;
    // Generate the nav bar.
    for (let i = 0; i <= NAV_BAR_RANGE; i+=1) {
        if (chunk_index +i == chunked_masterlist.length) {
            break;
        }
        forward =i;
    }

    for (let i = 0; i <= NAV_BAR_RANGE; i+=1) {
        if (chunk_index -i < 0) {
            break;
        }
        backward =i;
    }
    
    let buttons = []

    // Generate backwards nav bar buttons.
    if (backward > 0) {
        let beginning = document.createElement('button');
        beginning.onclick = function(){ insert_url_param("page", 1) };
        beginning.innerText = "<<";
        buttons.push(beginning);

        let previous = document.createElement('button');
        previous.onclick=function(){ insert_url_param("page", chunk_index) };
        previous.innerText = "<";
        buttons.push(previous);

        for (i = chunk_index - backward; i < chunk_index; i+=1) {
            let button = document.createElement('button');
            let n = i+1
            button.onclick=function(){ insert_url_param("page", n) };
            button.innerText = i+1;
            buttons.push(button);
        }
    }

    // Generate current navbar button.
    let current = document.createElement('button');
    current.innerText = chunk_index +1;
    current.disabled = true;
    buttons.push(current);

    // Generate forward navbar buttons.
    if (forward > 0) {
        for (i = chunk_index+1; i <= chunk_index + forward; i+=1) {
            let button = document.createElement('button');
            let n = i+1
            button.onclick=function(){ insert_url_param("page", n) };
            button.innerText = i+1;
            buttons.push(button);
        }

        let next = document.createElement('button');
        next.onclick=function(){ insert_url_param("page", chunk_index+2) };
        next.innerText = ">";
        buttons.push(next);

        let end = document.createElement('button');
        end.onclick=function(){ insert_url_param("page", chunked_masterlist.length) };
        end.innerText = ">>";
        buttons.push(end);
    }

    for (i in buttons) {
        document.getElementById("gallery_nav_bar").appendChild(buttons[i]);
    }
}